@@ -19,9 +19,9 @@
 
 from cubicweb import tags, uilib
 from cubicweb.utils import UStringIO
-from cubicweb.web import formfields, formwidgets
-from cubicweb.web.views.owl import OWL_TYPE_MAP
-from cubicweb.view import EntityView
+from cubicweb_web import formfields, formwidgets
+from cubicweb_web.views.owl import OWL_TYPE_MAP
+from cubicweb_web.view import EntityView
 from cubicweb.predicates import match_kwargs
 
 try:
